@@ -17,8 +17,8 @@
  * along with this program.  If not, see <http://www.gnu.org/licenses/>.
  */
 
-#include "logging.h"
 #include "x11inputdevice.h"
+#include "logging.h"
 
 #include <QStringList>
 
@@ -31,23 +31,25 @@ using namespace Wacom;
 /**
  * Class for private members.
  */
-namespace Wacom {
-    class X11InputDevicePrivate
-    {
-        public:
-            QString name;
-            uint8_t deviceid;
-    };
+namespace Wacom
+{
+class X11InputDevicePrivate
+{
+public:
+    QString name;
+    uint8_t deviceid;
+};
 }
 
-
-X11InputDevice::X11InputDevice() : d_ptr(new X11InputDevicePrivate)
+X11InputDevice::X11InputDevice()
+    : d_ptr(new X11InputDevicePrivate)
 {
     Q_D(X11InputDevice);
     d->deviceid = 0;
 }
 
-X11InputDevice::X11InputDevice(X11InputDevice::XID id, const QString& name) : d_ptr(new X11InputDevicePrivate)
+X11InputDevice::X11InputDevice(X11InputDevice::XID id, const QString &name)
+    : d_ptr(new X11InputDevicePrivate)
 {
     Q_D(X11InputDevice);
     d->deviceid = 0;
@@ -55,9 +57,8 @@ X11InputDevice::X11InputDevice(X11InputDevice::XID id, const QString& name) : d_
     open(id, name);
 }
 
-
-
-X11InputDevice::X11InputDevice(const X11InputDevice& device) : d_ptr(new X11InputDevicePrivate)
+X11InputDevice::X11InputDevice(const X11InputDevice &device)
+    : d_ptr(new X11InputDevicePrivate)
 {
     Q_D(X11InputDevice);
     d->deviceid = 0;
@@ -65,16 +66,13 @@ X11InputDevice::X11InputDevice(const X11InputDevice& device) : d_ptr(new X11Inpu
     operator=(device);
 }
 
-
 X11InputDevice::~X11InputDevice()
 {
     close();
     delete d_ptr;
 }
 
-
-
-X11InputDevice& X11InputDevice::operator= (const X11InputDevice& that)
+X11InputDevice &X11InputDevice::operator=(const X11InputDevice &that)
 {
     // close current device
     close();
@@ -87,8 +85,6 @@ X11InputDevice& X11InputDevice::operator= (const X11InputDevice& that)
     return *this;
 }
 
-
-
 bool X11InputDevice::close()
 {
     Q_D(X11InputDevice);
@@ -100,20 +96,17 @@ bool X11InputDevice::close()
 
     xcb_input_close_device(QX11Info::connection(), d->deviceid);
 
-    d->deviceid  = 0;
+    d->deviceid = 0;
     d->name.clear();
 
     return true;
 }
 
-
-
-bool X11InputDevice::getAtomProperty(const QString& property, QList< long int >& values, long int nelements) const
+bool X11InputDevice::getAtomProperty(const QString &property, QList<long int> &values, long int nelements) const
 {
     return getProperty<long>(property, XCB_ATOM_ATOM, nelements, values);
 }
 
-
 const QVector<uint8_t> X11InputDevice::getDeviceButtonMapping() const
 {
     Q_D(const X11InputDevice);
@@ -127,16 +120,16 @@ const QVector<uint8_t> X11InputDevice::getDeviceButtonMapping() const
     int buttonCount = 0;
 
     xcb_input_get_device_button_mapping_cookie_t cookie = xcb_input_get_device_button_mapping(QX11Info::connection(), d->deviceid);
-    xcb_input_get_device_button_mapping_reply_t* reply = xcb_input_get_device_button_mapping_reply(QX11Info::connection(), cookie, nullptr);
+    xcb_input_get_device_button_mapping_reply_t *reply = xcb_input_get_device_button_mapping_reply(QX11Info::connection(), cookie, nullptr);
 
     if (!reply) {
         return buttonMap; // the device has no buttons
     }
 
-    uint8_t* map_return = xcb_input_get_device_button_mapping_map(reply);
+    uint8_t *map_return = xcb_input_get_device_button_mapping_map(reply);
     buttonCount = xcb_input_get_device_button_mapping_map_length(reply);
 
-    for (int i = 0 ; i < buttonCount ; ++i) {
+    for (int i = 0; i < buttonCount; ++i) {
         buttonMap.append(map_return[i]);
     }
 
@@ -145,8 +138,6 @@ const QVector<uint8_t> X11InputDevice::getDeviceButtonMapping() const
     return buttonMap;
 }
 
-
-
 long X11InputDevice::getDeviceId() const
 {
     Q_D(const X11InputDevice);
@@ -158,16 +149,14 @@ long X11InputDevice::getDeviceId() const
     return d->deviceid;
 }
 
-
-
-bool X11InputDevice::getFloatProperty(const QString& property, QList< float >& values, long int nelements) const
+bool X11InputDevice::getFloatProperty(const QString &property, QList<float> &values, long int nelements) const
 {
     if (!isOpen()) {
         return false;
     }
 
     xcb_intern_atom_cookie_t cookie = xcb_intern_atom(QX11Info::connection(), false, strlen("FLOAT"), "FLOAT");
-    xcb_intern_atom_reply_t* reply = xcb_intern_atom_reply(QX11Info::connection(), cookie, nullptr);
+    xcb_intern_atom_reply_t *reply = xcb_intern_atom_reply(QX11Info::connection(), cookie, nullptr);
 
     xcb_atom_t expectedType = XCB_ATOM_NONE;
 
@@ -184,44 +173,38 @@ bool X11InputDevice::getFloatProperty(const QString& property, QList< float >& v
     return getProperty<float>(property, expectedType, nelements, values);
 }
 
-
-
-bool X11InputDevice::getLongProperty(const QString& property, QList< long int >& values, long int nelements) const
+bool X11InputDevice::getLongProperty(const QString &property, QList<long int> &values, long int nelements) const
 {
     return getProperty<long>(property, XCB_ATOM_INTEGER, nelements, values);
 }
 
-
-
-const QString& X11InputDevice::getName() const
+const QString &X11InputDevice::getName() const
 {
     Q_D(const X11InputDevice);
     return d->name;
 }
 
-
-
-bool X11InputDevice::getStringProperty(const QString& property, QList< QString >& values, long int nelements) const
+bool X11InputDevice::getStringProperty(const QString &property, QList<QString> &values, long int nelements) const
 {
     // get property data & values
-    unsigned long  nitems         = 0;
-    int            expectedFormat = 8;
+    unsigned long nitems = 0;
+    int expectedFormat = 8;
 
-    xcb_input_get_device_property_reply_t* reply = getPropertyData(property, XCB_ATOM_STRING, expectedFormat, nelements);
+    xcb_input_get_device_property_reply_t *reply = getPropertyData(property, XCB_ATOM_STRING, expectedFormat, nelements);
     if (!reply) {
         return false;
     }
 
-    unsigned char* strData = static_cast<unsigned char*>(xcb_input_get_device_property_items(reply));
+    unsigned char *strData = static_cast<unsigned char *>(xcb_input_get_device_property_items(reply));
     nitems = reply->num_items;
 
-    for (unsigned long i = 0 ; i < nitems ; ++i) {
+    for (unsigned long i = 0; i < nitems; ++i) {
         // add first string value up to '\0'
-        QString value = QLatin1String ((const char*)strData);
+        QString value = QLatin1String((const char *)strData);
         values.append(value);
 
         // ++i will jump over '\0'
-        i       += value.length();
+        i += value.length();
         strData += value.length();
     }
 
@@ -229,9 +212,7 @@ bool X11InputDevice::getStringProperty(const QString& property, QList< QString >
     return true;
 }
 
-
-
-bool X11InputDevice::hasProperty(const QString& property) const
+bool X11InputDevice::hasProperty(const QString &property) const
 {
     Q_D(const X11InputDevice);
 
@@ -246,15 +227,15 @@ bool X11InputDevice::hasProperty(const QString& property) const
         return false;
     }
 
-    bool  found  = false;
+    bool found = false;
 
     xcb_input_list_device_properties_cookie_t cookie = xcb_input_list_device_properties(QX11Info::connection(), d->deviceid);
-    xcb_input_list_device_properties_reply_t* reply = xcb_input_list_device_properties_reply(QX11Info::connection(), cookie, nullptr);
+    xcb_input_list_device_properties_reply_t *reply = xcb_input_list_device_properties_reply(QX11Info::connection(), cookie, nullptr);
 
     if (reply) {
-        xcb_atom_t* atoms = xcb_input_list_device_properties_atoms(reply);
+        xcb_atom_t *atoms = xcb_input_list_device_properties_atoms(reply);
 
-        for (int i = 0 ; i < reply->num_atoms; ++i) {
+        for (int i = 0; i < reply->num_atoms; ++i) {
             if (atoms[i] == atom) {
                 found = true;
                 break;
@@ -266,23 +247,18 @@ bool X11InputDevice::hasProperty(const QString& property) const
     return found;
 }
 
-
-
 bool X11InputDevice::isOpen() const
 {
     Q_D(const X11InputDevice);
     return (d->deviceid != 0);
 }
 
-
-
 bool X11InputDevice::isTabletDevice()
 {
     return hasProperty(QLatin1String("Wacom Tool Type"));
 }
 
-
-bool X11InputDevice::open(X11InputDevice::XID id, const QString& name)
+bool X11InputDevice::open(X11InputDevice::XID id, const QString &name)
 {
     Q_D(X11InputDevice);
 
@@ -296,7 +272,7 @@ bool X11InputDevice::open(X11InputDevice::XID id, const QString& name)
     }
 
     xcb_input_open_device_cookie_t cookie = xcb_input_open_device(QX11Info::connection(), id);
-    xcb_input_open_device_reply_t* reply = xcb_input_open_device_reply(QX11Info::connection(), cookie, nullptr);
+    xcb_input_open_device_reply_t *reply = xcb_input_open_device_reply(QX11Info::connection(), cookie, nullptr);
 
     if (reply == nullptr) {
         // some virtual devices can not be opened
@@ -305,14 +281,12 @@ bool X11InputDevice::open(X11InputDevice::XID id, const QString& name)
     }
     free(reply);
 
-    d->deviceid  = id;
-    d->name    = name;
+    d->deviceid = id;
+    d->name = name;
 
     return true;
 }
 
-
-
 bool X11InputDevice::setDeviceButtonMapping(const QVector<uint8_t> &buttonMap) const
 {
     Q_D(const X11InputDevice);
@@ -322,8 +296,8 @@ bool X11InputDevice::setDeviceButtonMapping(const QVector<uint8_t> &buttonMap) c
     }
 
     xcb_input_set_device_button_mapping_cookie_t cookie =
-            xcb_input_set_device_button_mapping(QX11Info::connection(), d->deviceid, static_cast<uint8_t>(buttonMap.size()), buttonMap.data());
-    xcb_input_set_device_button_mapping_reply_t* reply = xcb_input_set_device_button_mapping_reply(QX11Info::connection(), cookie, nullptr);
+        xcb_input_set_device_button_mapping(QX11Info::connection(), d->deviceid, static_cast<uint8_t>(buttonMap.size()), buttonMap.data());
+    xcb_input_set_device_button_mapping_reply_t *reply = xcb_input_set_device_button_mapping_reply(QX11Info::connection(), cookie, nullptr);
 
     uint8_t result = 1;
 
@@ -335,18 +309,16 @@ bool X11InputDevice::setDeviceButtonMapping(const QVector<uint8_t> &buttonMap) c
     return (result == 0);
 }
 
-
-
-bool X11InputDevice::setFloatProperty(const QString& property, const QString& values) const
+bool X11InputDevice::setFloatProperty(const QString &property, const QString &values) const
 {
-    QStringList valueList = values.split (QLatin1String(" "));
+    QStringList valueList = values.split(QLatin1String(" "));
 
-    bool         ok;
-    QString      svalue;
-    float        fvalue;
+    bool ok;
+    QString svalue;
+    float fvalue;
     QList<float> fvalues;
 
-    for (int i = 0  ; i < valueList.size() ; ++i) {
+    for (int i = 0; i < valueList.size(); ++i) {
         svalue = valueList.at(i);
 
         if (svalue.isEmpty()) {
@@ -366,16 +338,14 @@ bool X11InputDevice::setFloatProperty(const QString& property, const QString& va
     return setFloatProperty(property, fvalues);
 }
 
-
-
-bool X11InputDevice::setFloatProperty(const QString& property, const QList< float >& values) const
+bool X11InputDevice::setFloatProperty(const QString &property, const QList<float> &values) const
 {
     if (!isOpen()) {
         return false;
     }
 
     xcb_intern_atom_cookie_t cookie = xcb_intern_atom(QX11Info::connection(), false, strlen("FLOAT"), "FLOAT");
-    xcb_intern_atom_reply_t* reply = xcb_intern_atom_reply(QX11Info::connection(), cookie, nullptr);
+    xcb_intern_atom_reply_t *reply = xcb_intern_atom_reply(QX11Info::connection(), cookie, nullptr);
 
     xcb_atom_t expectedType = XCB_ATOM_NONE;
 
@@ -392,19 +362,16 @@ bool X11InputDevice::setFloatProperty(const QString& property, const QList< floa
     return setProperty<float>(property, expectedType, values);
 }
 
-
-
-bool X11InputDevice::setLongProperty(const QString& property, const QString& values) const
+bool X11InputDevice::setLongProperty(const QString &property, const QString &values) const
 {
-    QStringList valueList = values.split (QLatin1String(" "));
+    QStringList valueList = values.split(QLatin1String(" "));
 
-    bool        ok;
-    QString     svalue;
-    long        lvalue = 0;
+    bool ok;
+    QString svalue;
+    long lvalue = 0;
     QList<long> lvalues;
 
-    for (int i = 0  ; i < valueList.size() ; ++i) {
-
+    for (int i = 0; i < valueList.size(); ++i) {
         svalue = valueList.at(i);
 
         if (svalue.isEmpty()) {
@@ -424,32 +391,27 @@ bool X11InputDevice::setLongProperty(const QString& property, const QString& val
     return setLongProperty(property, lvalues);
 }
 
-
-
-bool X11InputDevice::setLongProperty(const QString& property, const QList< long int >& values) const
+bool X11InputDevice::setLongProperty(const QString &property, const QList<long int> &values) const
 {
     return setProperty<long>(property, XCB_ATOM_INTEGER, values);
 }
 
-
-
-
 template<typename T>
-bool X11InputDevice::getProperty(const QString& property, X11InputDevice::Atom expectedType, long int nelements, QList< T >& values) const
+bool X11InputDevice::getProperty(const QString &property, X11InputDevice::Atom expectedType, long int nelements, QList<T> &values) const
 {
     // get property data & values
-    uint32_t*      data           = nullptr;
-    unsigned long  nitems         = 0;
-    int            expectedFormat = 32;
+    uint32_t *data = nullptr;
+    unsigned long nitems = 0;
+    int expectedFormat = 32;
 
-    xcb_input_get_device_property_reply_t* reply = getPropertyData(property, expectedType, expectedFormat, nelements);
+    xcb_input_get_device_property_reply_t *reply = getPropertyData(property, expectedType, expectedFormat, nelements);
     if (!reply) {
         return false;
     }
-    data = static_cast<uint32_t*>(xcb_input_get_device_property_items(reply));
+    data = static_cast<uint32_t *>(xcb_input_get_device_property_items(reply));
     nitems = reply->num_items;
 
-    for (unsigned long i = 0 ; i < nitems ; ++i) {
+    for (unsigned long i = 0; i < nitems; ++i) {
         T replyData = 0;
         memcpy(&replyData, data + i, sizeof(uint32_t));
 
@@ -461,20 +423,19 @@ bool X11InputDevice::getProperty(const QString& property, X11InputDevice::Atom e
     return true;
 }
 
-
-
-xcb_input_get_device_property_reply_t* X11InputDevice::getPropertyData (const QString& property, X11InputDevice::Atom expectedType, int expectedFormat, long int nelements) const
+xcb_input_get_device_property_reply_t *
+X11InputDevice::getPropertyData(const QString &property, X11InputDevice::Atom expectedType, int expectedFormat, long int nelements) const
 {
     Q_D(const X11InputDevice);
 
     // check parameters
     if (!isOpen()) {
-        qCWarning(COMMON) << QString::fromLatin1 ("Can not get XInput property '%1' as no device was opened!").arg(property);
+        qCWarning(COMMON) << QString::fromLatin1("Can not get XInput property '%1' as no device was opened!").arg(property);
         return nullptr;
     }
 
     if (nelements < 1) {
-        qCWarning(COMMON) << QString::fromLatin1 ("Can not get XInput property '%1' as less than one element was requested!").arg(property);
+        qCWarning(COMMON) << QString::fromLatin1("Can not get XInput property '%1' as less than one element was requested!").arg(property);
         return nullptr;
     }
 
@@ -487,11 +448,12 @@ xcb_input_get_device_property_reply_t* X11InputDevice::getPropertyData (const QS
     }
 
     // get device property and validate it
-    Atom           actualType   = XCB_ATOM_NONE;
-    int            actualFormat = 0;
+    Atom actualType = XCB_ATOM_NONE;
+    int actualFormat = 0;
 
-    xcb_input_get_device_property_cookie_t cookie = xcb_input_get_device_property(QX11Info::connection(), propertyAtom, XCB_ATOM_ANY, 0, nelements, d->deviceid, false);
-    xcb_input_get_device_property_reply_t* reply = xcb_input_get_device_property_reply(QX11Info::connection(), cookie, nullptr);
+    xcb_input_get_device_property_cookie_t cookie =
+        xcb_input_get_device_property(QX11Info::connection(), propertyAtom, XCB_ATOM_ANY, 0, nelements, d->deviceid, false);
+    xcb_input_get_device_property_reply_t *reply = xcb_input_get_device_property_reply(QX11Info::connection(), cookie, nullptr);
 
     if (reply) {
         actualType = reply->type;
@@ -502,7 +464,13 @@ xcb_input_get_device_property_reply_t* X11InputDevice::getPropertyData (const QS
     }
 
     if (actualFormat != expectedFormat || actualType != expectedType) {
-        qCWarning(COMMON) << QString::fromLatin1("Can not process incompatible Xinput property '%1': Format is '%2', expected was '%3'. Type is '%4', expected was '%5'.").arg(property).arg(actualFormat).arg(expectedFormat).arg(actualType).arg(expectedType);
+        qCWarning(COMMON) << QString::fromLatin1(
+                                 "Can not process incompatible Xinput property '%1': Format is '%2', expected was '%3'. Type is '%4', expected was '%5'.")
+                                 .arg(property)
+                                 .arg(actualFormat)
+                                 .arg(expectedFormat)
+                                 .arg(actualType)
+                                 .arg(expectedType);
         free(reply);
         return nullptr;
     }
@@ -510,16 +478,14 @@ xcb_input_get_device_property_reply_t* X11InputDevice::getPropertyData (const QS
     return reply;
 }
 
-
-
-bool X11InputDevice::lookupProperty(const QString& property, X11InputDevice::Atom &atom) const
+bool X11InputDevice::lookupProperty(const QString &property, X11InputDevice::Atom &atom) const
 {
     if (!isOpen() || property.isEmpty()) {
         return false;
     }
 
     xcb_intern_atom_cookie_t cookie = xcb_intern_atom(QX11Info::connection(), false, property.toLatin1().length(), property.toLatin1().constData());
-    xcb_intern_atom_reply_t* reply = xcb_intern_atom_reply(QX11Info::connection(), cookie, nullptr);
+    xcb_intern_atom_reply_t *reply = xcb_intern_atom_reply(QX11Info::connection(), cookie, nullptr);
 
     if (reply) {
         atom = reply->atom;
@@ -536,10 +502,8 @@ bool X11InputDevice::lookupProperty(const QString& property, X11InputDevice::Ato
     return true;
 }
 
-
-
 template<typename T>
-bool X11InputDevice::setProperty(const QString& property, X11InputDevice::Atom expectedType, const QList< T >& values) const
+bool X11InputDevice::setProperty(const QString &property, X11InputDevice::Atom expectedType, const QList<T> &values) const
 {
     Q_D(const X11InputDevice);
 
@@ -547,12 +511,12 @@ bool X11InputDevice::setProperty(const QString& property, X11InputDevice::Atom e
 
     // check parameters
     if (!isOpen()) {
-        qCWarning(COMMON) << QString::fromLatin1 ("Can not set XInput property '%1' as no device was opened!").arg(property);
+        qCWarning(COMMON) << QString::fromLatin1("Can not set XInput property '%1' as no device was opened!").arg(property);
         return false;
     }
 
     if (values.size() == 0) {
-        qCWarning(COMMON) << QString::fromLatin1 ("Can not set XInput property '%1' as no values were provided!").arg(property);
+        qCWarning(COMMON) << QString::fromLatin1("Can not set XInput property '%1' as no values were provided!").arg(property);
         return false;
     }
 
@@ -565,11 +529,12 @@ bool X11InputDevice::setProperty(const QString& property, X11InputDevice::Atom e
     }
 
     // get property and validate format and type
-    Atom           actualType;
-    int            actualFormat;
+    Atom actualType;
+    int actualFormat;
 
-    xcb_input_get_device_property_cookie_t cookie = xcb_input_get_device_property(QX11Info::connection(), propertyAtom, XCB_ATOM_ANY, 0, values.size(), d->deviceid, false);
-    xcb_input_get_device_property_reply_t* reply = xcb_input_get_device_property_reply(QX11Info::connection(), cookie, nullptr);
+    xcb_input_get_device_property_cookie_t cookie =
+        xcb_input_get_device_property(QX11Info::connection(), propertyAtom, XCB_ATOM_ANY, 0, values.size(), d->deviceid, false);
+    xcb_input_get_device_property_reply_t *reply = xcb_input_get_device_property_reply(QX11Info::connection(), cookie, nullptr);
 
     if (reply) {
         actualType = reply->type;
@@ -581,15 +546,21 @@ bool X11InputDevice::setProperty(const QString& property, X11InputDevice::Atom e
     }
 
     if (actualFormat != expectedFormat || actualType != expectedType) {
-        qCWarning(COMMON) << QString::fromLatin1("Can not process incompatible Xinput property '%1': Format is '%2', expected was '%3'. Type is '%4', expected was '%5'.").arg(property).arg(actualFormat).arg(expectedFormat).arg(actualType).arg(expectedType);
+        qCWarning(COMMON) << QString::fromLatin1(
+                                 "Can not process incompatible Xinput property '%1': Format is '%2', expected was '%3'. Type is '%4', expected was '%5'.")
+                                 .arg(property)
+                                 .arg(actualFormat)
+                                 .arg(expectedFormat)
+                                 .arg(actualType)
+                                 .arg(expectedType);
         return false;
     }
 
     // create new data array - for XInput1 the data always to be of type long
     uint32_t *data = new uint32_t[values.size()];
 
-    for (int i = 0 ; i < values.size() ; ++i) {
-        const T& value = values.at(i);
+    for (int i = 0; i < values.size(); ++i) {
+        const T &value = values.at(i);
         memcpy(data + i, &value, sizeof(uint32_t));
     }
 
@@ -603,4 +574,3 @@ bool X11InputDevice::setProperty(const QString& property, X11InputDevice::Atom e
 
     return true;
 }
-
